@@ -112,12 +112,23 @@ impl Packages {
         org: &str,
         token: &str,
     ) -> Result<()> {
+        let mut query = String::new();
+        let mut query_args: Vec<String> = Default::default();
+        if !token.is_empty() {
+            query_args.push(format!("token={}", token));
+        }
+        for (i, n) in query_args.iter().enumerate() {
+            if i > 0 {
+                query.push('&');
+            }
+            query.push_str(n);
+        }
         let url = format!(
-            "/orgs/{}/packages/{}/{}/restore?token={}",
+            "/orgs/{}/packages/{}/{}/restore?{}",
             crate::progenitor_support::encode_path(&org.to_string()),
             crate::progenitor_support::encode_path(&package_type.to_string()),
             crate::progenitor_support::encode_path(&package_name.to_string()),
-            token.to_string(),
+            query
         );
 
         self.client.post(&url, None).await
@@ -153,14 +164,27 @@ impl Packages {
         per_page: i64,
         state: crate::types::PackagesGetAllPackageVersionsOwnedByOrgState,
     ) -> Result<Vec<crate::types::PackageVersion>> {
+        let mut query = String::new();
+        let mut query_args: Vec<String> = Default::default();
+        if page > 0 {
+            query_args.push(format!("page={}", page));
+        }
+        if per_page > 0 {
+            query_args.push(format!("per_page={}", per_page));
+        }
+        query_args.push(format!("state={}", state));
+        for (i, n) in query_args.iter().enumerate() {
+            if i > 0 {
+                query.push('&');
+            }
+            query.push_str(n);
+        }
         let url = format!(
-            "/orgs/{}/packages/{}/{}/versions?page={}&per_page={}&state={}",
+            "/orgs/{}/packages/{}/{}/versions?{}",
             crate::progenitor_support::encode_path(&org.to_string()),
             crate::progenitor_support::encode_path(&package_type.to_string()),
             crate::progenitor_support::encode_path(&package_name.to_string()),
-            format!("{}", page),
-            format!("{}", per_page),
-            state,
+            query
         );
 
         self.client.get(&url).await
@@ -187,12 +211,21 @@ impl Packages {
         org: &str,
         state: crate::types::PackagesGetAllPackageVersionsOwnedByOrgState,
     ) -> Result<Vec<crate::types::PackageVersion>> {
+        let mut query = String::new();
+        let mut query_args: Vec<String> = Default::default();
+        query_args.push(format!("state={}", state));
+        for (i, n) in query_args.iter().enumerate() {
+            if i > 0 {
+                query.push('&');
+            }
+            query.push_str(n);
+        }
         let url = format!(
-            "/orgs/{}/packages/{}/{}/versions?state={}",
+            "/orgs/{}/packages/{}/{}/versions?{}",
             crate::progenitor_support::encode_path(&org.to_string()),
             crate::progenitor_support::encode_path(&package_type.to_string()),
             crate::progenitor_support::encode_path(&package_name.to_string()),
-            state,
+            query
         );
 
         self.client.get_all_pages(&url).await
@@ -404,11 +437,22 @@ impl Packages {
         package_name: &str,
         token: &str,
     ) -> Result<()> {
+        let mut query = String::new();
+        let mut query_args: Vec<String> = Default::default();
+        if !token.is_empty() {
+            query_args.push(format!("token={}", token));
+        }
+        for (i, n) in query_args.iter().enumerate() {
+            if i > 0 {
+                query.push('&');
+            }
+            query.push_str(n);
+        }
         let url = format!(
-            "/user/packages/{}/{}/restore?token={}",
+            "/user/packages/{}/{}/restore?{}",
             crate::progenitor_support::encode_path(&package_type.to_string()),
             crate::progenitor_support::encode_path(&package_name.to_string()),
-            token.to_string(),
+            query
         );
 
         self.client.post(&url, None).await
@@ -442,13 +486,26 @@ impl Packages {
         per_page: i64,
         state: crate::types::PackagesGetAllPackageVersionsOwnedByOrgState,
     ) -> Result<Vec<crate::types::PackageVersion>> {
+        let mut query = String::new();
+        let mut query_args: Vec<String> = Default::default();
+        if page > 0 {
+            query_args.push(format!("page={}", page));
+        }
+        if per_page > 0 {
+            query_args.push(format!("per_page={}", per_page));
+        }
+        query_args.push(format!("state={}", state));
+        for (i, n) in query_args.iter().enumerate() {
+            if i > 0 {
+                query.push('&');
+            }
+            query.push_str(n);
+        }
         let url = format!(
-            "/user/packages/{}/{}/versions?page={}&per_page={}&state={}",
+            "/user/packages/{}/{}/versions?{}",
             crate::progenitor_support::encode_path(&package_type.to_string()),
             crate::progenitor_support::encode_path(&package_name.to_string()),
-            format!("{}", page),
-            format!("{}", per_page),
-            state,
+            query
         );
 
         self.client.get(&url).await
@@ -474,11 +531,20 @@ impl Packages {
         package_name: &str,
         state: crate::types::PackagesGetAllPackageVersionsOwnedByOrgState,
     ) -> Result<Vec<crate::types::PackageVersion>> {
+        let mut query = String::new();
+        let mut query_args: Vec<String> = Default::default();
+        query_args.push(format!("state={}", state));
+        for (i, n) in query_args.iter().enumerate() {
+            if i > 0 {
+                query.push('&');
+            }
+            query.push_str(n);
+        }
         let url = format!(
-            "/user/packages/{}/{}/versions?state={}",
+            "/user/packages/{}/{}/versions?{}",
             crate::progenitor_support::encode_path(&package_type.to_string()),
             crate::progenitor_support::encode_path(&package_name.to_string()),
-            state,
+            query
         );
 
         self.client.get_all_pages(&url).await
